@@ -142,7 +142,7 @@ ncb_hig_dialog (GtkMessageType type,
 					title);
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (error_dialog), "%s", reason);
 	gtk_window_set_title (GTK_WINDOW (error_dialog), "");
-	gtk_window_set_icon_name (GTK_WINDOW (error_dialog), "gnome-dev-cdrom");
+	gtk_window_set_icon_name (GTK_WINDOW (error_dialog), "nautilus-cd-burner");
 
 	gtk_container_set_border_width (GTK_CONTAINER (error_dialog), 5);
 
